#[non_exhaustive]pub enum EncodeError {
UnknownMnemonic,
OperandCountMismatch,
OperandCountRange {
min: u8,
max: u8,
got: u8,
},
OperandOutOfRange {
field: &'static str,
value: i64,
width: u8,
signed: bool,
},
ImmediateNotAligned {
field: &'static str,
value: i64,
scale: i64,
},
InvalidOperandKind {
field: &'static str,
expected: &'static str,
got: &'static str,
},
AmbiguousVariant,
NoMatchingVariant,
NoMatchingVariantHint {
hint: NoMatchingHint,
},
}Expand description
Encoder errors.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnknownMnemonic
The mnemonic is unknown in the spec set.
OperandCountMismatch
The provided operand count does not match any variant for the mnemonic.
OperandCountRange
The provided operand count is outside the valid range for the mnemonic.
Fields
OperandOutOfRange
An operand value does not fit its target field.
Fields
ImmediateNotAligned
Immediate must satisfy a scale/alignment constraint before encoding.
Fields
InvalidOperandKind
Operand kind does not match expected field kind.
Fields
AmbiguousVariant
Multiple variants matched equally.
NoMatchingVariant
No variant matched the provided operands.
NoMatchingVariantHint
No variant matched, with a structured hint.
Fields

hint: NoMatchingHintStructured guidance for adjusting operand shape.