encode

Function encode 

pub fn encode(
    specs: &[EncodingSpec],
    mnemonic: &str,
    operands: &[Operand],
) -> Result<InstructionCode, EncodeError>
Selects a variant by mnemonic and typed operands and encodes it.

Errors

Returns EncodeError if no variant can be selected and encoded unambiguously.